 [![PyPI Version](https://badge.fury.io/py/sc-config.svg)](https://badge.fury.io/py/sc-config)
 [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/sc-config)](https://img.shields.io/pypi/pyversions/sc-config)

# A simple Python configuration file operator

This project provides a common way to read configurations using [config42](https://pypi.org/project/config42/).

## Installation

It is possible to install the tool with pip:

```
pip install sc-config
```

## Configuration

You can copy [default.yml](tests/sample_config/default.yml) to `~/.<project-name>/production.yml`
to initialize the production configuration.

- See [default.yml](tests/sample_config/default.yml) for more information.

## Dependencies

- config42 0.4.4

## Changes

- Version 0.0.1

  - Initial version

## License

The script is released under the [MIT License](https://opensource.org/licenses/MIT). 
The MIT License is registered with and approved by the [Open Source Initiative](https://opensource.org/).
